@@ -32,14 +32,10 @@ class DeltaCenterArguments:
     backbone_model: str = field(default="",
                                 metadata={"help": "The backbone model of the delta model"}
     )
-    model_path_public: str = field(
+    backbone_model_path_public: str = field(
         default = None,
         metadata={"help": "Publicly available path (url) to pretrained model or model identifier from huggingface.co/models"}
     )
-    model_revision: str = field(
-        default="main",
-        metadata={"help": "The specific model version to use (can be a branch name, tag name or commit id)."},
-    )
     delta_type: str = field(
         default=None,
         metadata={"help": "the type of type model, e.g., adapter, lora, etc."}
@@ -48,6 +44,10 @@ class DeltaCenterArguments:
         default=None,
         metadata={"help": "the task(s） that the delta is trained on"}
     )
+    train_datasets: Optional[Union[List[str], str]]= field(
+        default=None,
+        metadata={"help": "the datasets(s） that the delta is trained on"}
+    )
     checkpoint_size: Optional[float] = field(
         default=None,
         metadata={"help": "the size of the checkpoint, in MB"}
@@ -56,6 +56,10 @@ class DeltaCenterArguments:
         default=None,
         metadata={"help": "the task(s) that the delta is tested on"}
     )
+    test_datasets: Optional[Union[List[str], str]] = field(
+        default=None,
+        metadata={"help": "the dataset(s) that the delta is tested on"}
+    )
     test_performance: Optional[float] = field(
         default=None,
         metadata={"help": "the performance of the model on the test set"}
@@ -72,6 +76,14 @@ class DeltaCenterArguments:
         default=None,
         metadata={"help": "the ratio of delta parameters in the model"}
     )
+    usage_code: Optional[str] = field(
+        default="",
+        metadata={"help": "the usage code of the model"}
+    )
+    license: Optional[str] = field(
+        default="apache-2.0",
+        metadata={"help": "the license of the model"}
+    )
 
 
 
@@ -96,6 +108,7 @@ class SaveLoadMixin:
         list_tags: Optional[List] = list(),
         dict_tags: Optional[Dict] = dict(),
         delay_push: bool = False,
+        usage_code: Optional[str] = "",
     ):
         r"""
         Save a model and its configuration file to a directory, so that it can be re-loaded using the
@@ -353,10 +366,21 @@ class SaveLoadMixin:
             logger.info("Name is not set, use default name.")
             mdict['name'] = self.create_default_name(**mdict)
 
+        if len(mdict['usage']) == 0:
+            logger.info("Usage is not set, use default usage.")
+            mdict['usage'] = self.create_default_usage(mdict['name'])
+
 
         center_args = DeltaCenterArguments(**mdict)
         return  center_args
 
+    def create_default_usage(self, name):
+        usage_str = """from opendelta import AutoDeltaModel\n""" + \
+            """delta_model = AutoDeltaModel.from_finetuned({name_with_userid}, backbone_model=model)\n""" + \
+            """delta_model.freeze_module() # if you are going to further train it \n""" + \
+            """delta_model.log()"""
+        return usage_str
+
     def create_default_name(self, **kwargs):
         r"""Currently, it's only a simple concatenation of the arguments.
         """
